***********
Basic Usage
***********

Installation
============
Install ``visible_residues`` using ``pip``::

    $ pip install visible_residues

- Requires python≥3.10
- `Semantic versioning`_.

.. _`semantic versioning`: https://semver.org/
